@@ -40,15 +40,20 @@ def pvalf(name, val, units='', comment=''):
         re = val.real
         im = val.imag
         if val.imag < 0:
-            str_tmp = "\t{0:15s} = {1:8.3f} - j{2:7.3f}{3:15s}{4}"
+            str_tmp = "\t{0:20s}  {1:8.3f} - j{2:7.3f}{3:20s}{4}"
         else:
-            str_tmp = "\t{0:15s} = {1:8.3f} + j{2:7.3f}{3:15s}{4}"
+            str_tmp = "\t{0:20s}  {1:8.3f} + j{2:7.3f}{3:20s}{4}"
         print((str_tmp.format(name, re, abs(im), units, comment)))
 
     else:
-        str_tmp = "\t{0:15s} = {1:7.3f}\t{2:15s}{3}"
-        print((str_tmp.format(name, val, units, comment)))
-
+        if val < 1000:
+            str_tmp = "\t{0:20s} {1:7.3f}\t{2:20s}{3}"
+            print((str_tmp.format(name, val, units, comment)))
+        else:
+            number = "{:7.3e}".format(val)
+            number = number[:5] + ' ' + number[5:].upper()
+            str_tmp = "\t{0:20s}   {1}{2:20s}{3}"
+            print((str_tmp.format(name, number, units, comment)))
 
 def header(header_string):
     """Print a nice header to the terminal.
